==> haskell-src-exts-simple-1.23.1.0-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-exts-simple
version:              1.23.1.0
visibility:           public
id:                   haskell-src-exts-simple-1.23.1.0-1MAjaOdtYeKCwQLxJFGJQk
key:                  haskell-src-exts-simple-1.23.1.0-1MAjaOdtYeKCwQLxJFGJQk
license:              MIT
copyright:            2016-2024, Bertram Felgenhauer
maintainer:           Bertram Felgenhauer <int-e@gmx.de>
author:               Bertram Felgenhauer
homepage:             https://github.com/int-e/haskell-src-exts-simple
synopsis:             A simplified view on the haskell-src-exts AST
description:
    This package provides a shim for haskell-src-exts (HSE), exposing the
    same AST but without annotations, using ghc'\''s pattern synonyms.

    See README.md for further information and compatibility considerations.

category:             Development
abi:                  239feae4f702d628e9ccb5db05b9be02
exposed:              True
exposed-modules:
    Language.Haskell.Exts.Simple Language.Haskell.Exts.Simple.Build
    Language.Haskell.Exts.Simple.Extension
    Language.Haskell.Exts.Simple.Fixity
    Language.Haskell.Exts.Simple.Parser
    Language.Haskell.Exts.Simple.Pretty
    Language.Haskell.Exts.Simple.Syntax

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-simple-1.23.1.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-simple-1.23.1.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-simple-1.23.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-simple
hs-libraries:         HShaskell-src-exts-simple-1.23.1.0-1MAjaOdtYeKCwQLxJFGJQk
depends:
    base-4.17.2.1 haskell-src-exts-1.23.1-39CiWs2hI5XHO9P4VTYEiS

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-simple/html/haskell-src-exts-simple.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-exts-simple-1.23.1.0-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-exts-simple
version:              1.23.1.0
visibility:           public
id:                   haskell-src-exts-simple-1.23.1.0-8i52o9sx7oY17FZzFm4KyO
key:                  haskell-src-exts-simple-1.23.1.0-8i52o9sx7oY17FZzFm4KyO
license:              MIT
copyright:            2016-2024, Bertram Felgenhauer
maintainer:           Bertram Felgenhauer <int-e@gmx.de>
author:               Bertram Felgenhauer
homepage:             https://github.com/int-e/haskell-src-exts-simple
synopsis:             A simplified view on the haskell-src-exts AST
description:
    This package provides a shim for haskell-src-exts (HSE), exposing the
    same AST but without annotations, using ghc'\''s pattern synonyms.

    See README.md for further information and compatibility considerations.

category:             Development
abi:                  e5e30df28ae6086fb3f13f46add2984a
exposed:              True
exposed-modules:
    Language.Haskell.Exts.Simple Language.Haskell.Exts.Simple.Build
    Language.Haskell.Exts.Simple.Extension
    Language.Haskell.Exts.Simple.Fixity
    Language.Haskell.Exts.Simple.Parser
    Language.Haskell.Exts.Simple.Pretty
    Language.Haskell.Exts.Simple.Syntax

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-simple-1.23.1.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-simple-1.23.1.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-simple-1.23.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-simple
hs-libraries:         HShaskell-src-exts-simple-1.23.1.0-8i52o9sx7oY17FZzFm4KyO
depends:
    base-4.17.2.1 haskell-src-exts-1.23.1-2P1r0qe5mJL71TopHSvpQ6

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-simple/html/haskell-src-exts-simple.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
